The purpose of R-package smiles is to provide a useful collection of functions designed to apply sequential method in data synthesis and evidence evaluation. This package is developed based on meta (version 7.0-0) in R version 4.2.2 (2022-10-31 ucrt).
Current version consists of three functions, including a main function of
sequential analysis (i.e. DoTSA) and a visualization function
of sequential analysis, (i.e. PlotCoRNET).